aboutsummaryrefslogtreecommitdiffstats
path: root/server/src/main/java/com/vaadin/ui/RichTextArea.java
diff options
context:
space:
mode:
authorAleksi Hietanen <aleksi@vaadin.com>2016-08-08 13:41:56 +0300
committerVaadin Code Review <review@vaadin.com>2016-08-17 07:31:03 +0000
commita5575a9252f4e502624079c65c7080e741846692 (patch)
tree739061425eef0a9ce3e1de714b5590300b1eb4fd /server/src/main/java/com/vaadin/ui/RichTextArea.java
parent93d7a0d962d100ee807089a76d57d0621a238108 (diff)
downloadvaadin-framework-a5575a9252f4e502624079c65c7080e741846692.tar.gz
vaadin-framework-a5575a9252f4e502624079c65c7080e741846692.zip
Update TextField to extend AbstractFieldNew (#51)
- Changes input prompt to be based on the placeholder attribute. - Unifies TextChangeEvents with ValueChangeEvents. - add*Listener methods now return Registration objects, remove*Listener methods removed. Change-Id: Ie92506ae9db205bb0010ae9126c608c62ad023ff
Diffstat (limited to 'server/src/main/java/com/vaadin/ui/RichTextArea.java')
-rw-r--r--server/src/main/java/com/vaadin/ui/RichTextArea.java11
1 files changed, 6 insertions, 5 deletions
diff --git a/server/src/main/java/com/vaadin/ui/RichTextArea.java b/server/src/main/java/com/vaadin/ui/RichTextArea.java
index 57fcdc0a5e..499abcab59 100644
--- a/server/src/main/java/com/vaadin/ui/RichTextArea.java
+++ b/server/src/main/java/com/vaadin/ui/RichTextArea.java
@@ -22,6 +22,7 @@ import org.jsoup.nodes.Element;
import com.vaadin.data.Property;
import com.vaadin.legacy.ui.LegacyAbstractField;
+import com.vaadin.legacy.ui.LegacyTextField;
import com.vaadin.server.PaintException;
import com.vaadin.server.PaintTarget;
import com.vaadin.shared.ui.textarea.RichTextAreaState;
@@ -30,7 +31,7 @@ import com.vaadin.ui.declarative.DesignContext;
/**
* A simple RichTextArea to edit HTML format text.
*
* Note, that using {@link TextField#setMaxLength(int)} method in
* {@link RichTextArea} may produce unexpected results as formatting is counted
* into length of field.
*/
@@ -213,7 +214,7 @@ public class RichTextArea extends LegacyAbstractField<String> implements
* </p>
*
* @return the String Textual representation for null strings.
- * @see TextField#isNullSettingAllowed()
+ * @see LegacyTextField#isNullSettingAllowed()
*/
public String getNullRepresentation() {
return nullRepresentation;
@@ -237,7 +238,7 @@ public class RichTextArea extends LegacyAbstractField<String> implements
*
* @return boolean Should the null-string represenation be always converted
* to null-values.
- * @see TextField#getNullRepresentation()
+ * @see LegacyTextField#getNullRepresentation()
*/
public boolean isNullSettingAllowed() {
return nullSettingAllowed;
@@ -258,7 +259,7 @@ public class RichTextArea extends LegacyAbstractField<String> implements
*
* @param nullRepresentation
* Textual representation for null strings.
- * @see TextField#setNullSettingAllowed(boolean)
+ * @see LegacyTextField#setNullSettingAllowed(boolean)
*/
public void setNullRepresentation(String nullRepresentation) {
this.nullRepresentation = nullRepresentation;
@@ -283,7 +284,7 @@ public class RichTextArea extends LegacyAbstractField<String> implements
* @param nullSettingAllowed
* Should the null-string represenation be always converted to
* null-values.
- * @see TextField#getNullRepresentation()
+ * @see LegacyTextField#getNullRepresentation()
*/
public void setNullSettingAllowed(boolean nullSettingAllowed) {
this.nullSettingAllowed = nullSettingAllowed;
@@ -30,7 +31,7 @@ import com.vaadin.ui.declarative.DesignContext;
* A simple RichTextArea to edit HTML format text.
*
- * Note, that using {@link TextField#setMaxLength(int)} method in
+ * Note, that using {@link LegacyTextField#setMaxLength(int)} method in
* {@link RichTextArea} may produce unexpected results as formatting is counted
* into length of field.